aboutsummaryrefslogtreecommitdiffstats
path: root/sm/certlist.c
diff options
context:
space:
mode:
authorNIIBE Yutaka <[email protected]>2017-04-28 01:06:33 +0000
committerNIIBE Yutaka <[email protected]>2017-04-28 01:06:33 +0000
commit5c8fe5480964c282540c051b538e812851988422 (patch)
tree61da9fb34cfb67875bea2dc259741c0e9b8ca78f /sm/certlist.c
parentg10: For signing, prefer available card key when no -u option. (diff)
downloadgnupg-5c8fe5480964c282540c051b538e812851988422.tar.gz
gnupg-5c8fe5480964c282540c051b538e812851988422.zip
Spelling fixes in docs and comments.
-- In addition, fix trailing spaces in tests/inittests. GnuPG-bug-id: 3121 Reported-by: ka7 (klemens) Signed-off-by: NIIBE Yutaka <[email protected]>
Diffstat (limited to 'sm/certlist.c')
-rw-r--r--sm/certlist.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sm/certlist.c b/sm/certlist.c
index e493cda97..39ab03c5d 100644
--- a/sm/certlist.c
+++ b/sm/certlist.c
@@ -388,7 +388,7 @@ gpgsm_add_to_certlist (ctrl_t ctrl, const char *name, int secret,
if (!dup_certs)
gpgsm_add_cert_to_certlist (ctrl, cert, &dup_certs, 0);
/* We have to ignore ambigious names as long as
there only fault is a bad key usage. This is
required to support encryption and signing
certificates of the same subject.
@@ -532,7 +532,7 @@ gpgsm_find_cert (ctrl_t ctrl,
}
/* If we don't have the KEYID filter we need to check for
- ambigious search results. Note, that it is somehwat
+ ambiguous search results. Note, that it is somehwat
reasonable to assume that a specification of a KEYID
won't lead to ambiguous names. */
if (!rc && !keyid)
@@ -388,7 +388,7 @@ gpgsm_add_to_certlist (ctrl_t ctrl, const char *name, int secret,
if (!dup_certs)
gpgsm_add_cert_to_certlist (ctrl, cert, &dup_certs, 0);
- /* We have to ignore ambigious names as long as
+ /* We have to ignore ambiguous names as long as
there only fault is a bad key usage. This is
required to support encryption and signing